require("animation")
require("inventory")

Player = {}
Player.State = "Idle"
Player.Score = 0
Player.AllowMove = true
Player.Animations = {}
Player.Animations.Idle = Animation:new('source/magganidle.png', 8)
Player.Animations.Walk = Animation:new('source/magganwalk.png', 8)
Player.Animations.Pointer = Animation:new('source/pointer.png', 16)
Player.PosX = 320
Player.PosY = 180
Player.TargetX = 320
Player.TargetY = 180
Player.Health = {}
Player.Health.Max = 100
Player.Health.Current = 100
Player.Stamina = {}
Player.Stamina.Max = 100
Player.Stamina.Current = 100
Player.Inventory = Inventory:new()

function Player:new()
	object = {}
	setmetatable(object, self)
	self.__index = self
	return object
end

function Player:draw()
	if self.State == "Idle" then
		self.Animations.Idle:play(self.PosX, self.PosY)
	elseif self.State == "Walking" then
		self.Animations.Walk:play(self.PosX, self.PosY)
	else
		self.Animations.Idle:play(self.PosX, self.PosY)
	end
end

function Player:update(dt)
	-- Update animations
	self.Animations.Idle:update(dt)
	self.Animations.Walk:update(dt)
	self.Animations.Pointer:update(dt)

	-- Update position
	if (self.PosX < self.TargetX-3) or (self.PosX > self.TargetX+3) or (self.PosY < self.TargetY-3) or (self.PosY > self.TargetY+3) then
		self.State = "Walking"
		w = self.TargetX-self.PosX
		h = self.TargetY-self.PosY
		t = math.sqrt(math.pow(w, 2)+math.pow(h, 2))
		self.PosX = self.PosX + ((w/t)*dt)*100
		self.PosY = self.PosY + ((h/t)*dt)*100
	elseif not(self.PosX == self.TargetX) or not(self.PosY == self.TargetY) then
		self.State = "Idle"
		self.PosX = self.TargetX
		self.PosY = self.TargetY
	end

	-- Update stats
	if not(gameType == "Exploration") then
		if(self.Stamina.Current > 0) then
			if(self.State == "Walking") then
				if (gameType == "Easy") then
					self.Stamina.Current = self.Stamina.Current - (1.5*dt)
				elseif (gameType == "Normal") then
					self.Stamina.Current = self.Stamina.Current - (3*dt)
				elseif (gameType == "Hard") then
					self.Stamina.Current = self.Stamina.Current - (5*dt)
				end
			else
				if (gameType == "Easy") then
					-- No drain
				elseif (gameType == "Normal") then
					self.Stamina.Current = self.Stamina.Current - (0.25*dt)
				elseif (gameType == "Hard") then
					self.Stamina.Current = self.Stamina.Current - (1*dt)
				end
			end
		else
			self.Stamina.Current = 0
			if(self.Health.Current > 0) then
				if (gameType == "Easy") then
					self.Health.Current = self.Health.Current - (1*dt)
				elseif (gameType == "Normal") then
					self.Health.Current = self.Health.Current - (2*dt)
				elseif (gameType == "Hard") then
					self.Health.Current = self.Health.Current - (4*dt)
				end
			else
				self.Health.Current = 0
				-- Player is dead
			end
		end
	end
end

function Player:setTarget(x, y)
	self.TargetX = x
	self.TargetY = y
end